# CSS Rhythmic Sizing

## Editor’s Draft, 1 January 1970

Specification Metadata

This version:
  https://drafts.csswg.org/css-rhythm/
Latest published version:
  https://www.w3.org/TR/css-rhythm-1/
Test Suite:
  http://test.csswg.org/suites/css-rhythm-1_dev/nightly-unstable/
Editors:
  Koji Ishii (Google)
  Elika J. Etemad / fantasai (Invited Expert)
Issue Tracking:
  GitHub Issues
Suggest an Edit for this Spec:
  GitHub Editor

Copyright © 1970 W3C® (MIT, ERCIM, Keio, Beihang). W3C liability, trademark and permissive document license rules apply.

## Abstract

This module contains CSS features for aligning content size to multiple of unit size.

CSS is a language for describing the rendering of structured documents (such as HTML and XML) on screen, on paper, etc.

## Status of this document

This is a public copy of the editors’ draft. It is provided for discussion only and may change at any moment. Its publication here does not imply endorsement of its contents by W3C. Don’t cite this document other than as work in progress.

GitHub Issues are preferred for discussion of this specification. When filing an issue, please put the text “css-rhythm” in the title, preferably like this: “[css-rhythm] …summary of comment…”. All issues and comments are archived, and there is also a historical archive.

This document was produced by the CSS Working Group.

This document was produced by a group operating under the W3C Patent Policy. W3C maintains a public list of any patent disclosures made in connection with the deliverables of the group; that page also includes instructions for disclosing a patent. An individual who has actual knowledge of a patent which the individual believes contains Essential Claim(s) must disclose the information in accordance with section 6 of the W3C Patent Policy.

This document is governed by the 1 March 2019 W3C Process Document.

## 1. Introduction

This specification provides features to control sizes of CSS objects according to the rules desired by use cases.

Controlling sizes of CSS objects to be multiple of a unit is desired in many cases. This level of the specification focuses on following cases.

- Adjust heights of block-level boxes to multiples of the specified length.

- Adjust heights of line boxes to multiples of the specified length.

By stacking blocks at multiples, authors can align content across columns, pages, scroll-snapped bocks or multiple blocks placed absolutely to maintain vertical rhythm.

Also by controlling heights of line boxes, lines of text in different fonts can create consistent visuals to help readability.

Vertical rhythm kept through pictures and different size of text in a multi-column document.

### 1.1. East Asian Casual Vertical Rhythms

In East Asia, a casual variant of vertical rhythm is widely used.

Vertical rhythm is typically used in professional typography. While it improves readability, its spacing constraints require careful and well-thought design of spaces.

The East Asian casual variant was originally a product of technical constraints of traditional word processors in '80s. But when the technical constraints were lifted in more modern technologies, with the help of square-like visual of ideographic characters, East Asian authors preferred to keep parts of the characteristics.

In this variant of vertical rhythm, the requirement is loosened for the ease of use for non-professional authors. Text is still on the rhythm, so that the majority of ideographic characters are mostly on grid, but when author specifies borders, margins, or some other objects that may break the rhythm, the rhythm is shifted rather than forced. The strict vertical rhythm often surprises non-professional authors by forced jumps in such cases, while this variant combines rhythm on text and the ease of use for non-professional authors.

This variant was very widely accepted in East Asia since the middle of '90s, such that most major word processors used in East Asia provided similar features by default.

In East Asian publishing typography, the vertical rhythm is one of important properties, but its priority compared to other properties varies by types of documents. In single column documents, the priority is weaker than that of multi-column documents. Text should be on the vertical rhythm, but it is often preferred for borders, margins, or other properties to win over the rhythm. In such cases, the rhythm is shifted, similar to the casual variant.

In this specification, when the line-height-step property is used without combination of the block-step property or the line-grid property, it produces the similar effect as the East Asian casual vertical rhythm.

It may also serve good for East Asian publishing typography, depends on the desired strength of the vertical rhythm.

For other cases of vertical rhythm, it is expected that the block-step property or the line-grid property are used, or that the line-height-step property is used together with them.

## 2. Adjusting Block-level Box Heights

The most common typographic rhythm problems are block-level intrusions: when continuous paragraph-level text is interrupted by differently-sized content such as illustrations and headings, then the line-to-line rhythm can be thrown off. The block step properties allow such elements to be fitted to the rhythmic interval by constraining their height to a multiple of a specified step size. This allows content before and after the interruption to maintain a continuous rhythm.

Heads and blockquotes have varying font sizes and line heights, resulting in uneven text across columns.
Space inserted before and after blocks (shown with colored borders) restores vertical rhythm.

While consistent use of the block step properties can produce the strictly gridded layout needed for parallel content flows, per-element specification of the step size also allows some interruptions to take their natural size in the flow, restarting the vertical rhythm afterwards. This can be useful in single-column layouts where the vertical rhythm is important to maintain visual continuity, but there is nothing alongside to align to. In these casese, large interruptions which visually disconnect the flow before and after can prioritize optimal spacing around the item over strict adherence to a continouous grid (by specifying block-step: none, the initial value).

This proposal can be simplified down to just the block-step-size property, represented solely through its shortened form as block-step. This level will likely at most contain block-step-size and block-step-insert, leaving block-step-align and block-step-round to be added if the future demands. The full design is described herein for current discussion and future reference.

This proposal is currently defined to apply only to block-level boxes. This limitation is solely to simplify the first iteration; it should eventually be extended to all layout modes that honor specified heights.

### 2.1. Specifying the Step Size: the block-step-size property

Name: | block-step-size
Value: | none | <length>
Initial: | none
Applies to: | block-level boxes
Inherited: | no
Percentages: | N/A
Computed value: | specified keyword or absolute length
Canonical order: | per grammar
Animatable: | ???
Animation type: | by computed value type

This property defines the step unit for a block-level box’s block size. When the step unit is set to a positive <length>, the box’s outer height is rounded (see block-step-round) to the closest multiple of the unit. Negative <length> values are invalid.

Values other than none cause the box to establish an independent formatting context.

In situations where margins collapse, only the box’s own margin is considered in calculating its outer size.

When a box fragments, step sizing is applied per fragment.

### 2.2. Specifying the Spacing Type: the block-step-insert property

Name: | block-step-insert
Value: | margin | padding
Initial: | margin
Applies to: | block-level boxes
Inherited: | no
Percentages: | N/A
Computed value: | specified keyword
Canonical order: | per grammar
Animatable: | no
Animation type: | discrete

This property specifies whether extra spacing derived from applying block-step-size is inserted inside (like padding) or outside (like margin) the box’s border.

Values have the following meanings:

margin
  Any extra space resulting from a block-step-size-induced adjustment is inserted outside the box’s border, as extra margin.
padding
  Any extra space resulting from a block-step-size-induced adjustment is inserted inside the box’s border, as extra padding.

### 2.3. Specifying Alignment: the block-step-align property

Name: | block-step-align
Value: | auto | center | start | end
Initial: | auto
Applies to: | block-level boxes
Inherited: | no
Percentages: | N/A
Computed value: | specified keyword
Canonical order: | per grammar
Animatable: | no
Animation type: | discrete

This property specifies whether extra spacing derived from applying block-step-size is inserted before, inserted after, or split between both sides of the box.

Values have the following meanings:

auto
  If block-step-insert is margin: if align-self is start, end, or center, treat as that value, otherwise treat as center.
center
  Any extra space resulting from a block-step-size-induced adjustment is split, and applied half on either side of the box.
start
  Any extra space resulting from a block-step-size-induced adjustment is inserted on the end side of the box.
end
  Any extra space resulting from a block-step-size-induced adjustment is inserted on the start side of the box.

In all cases, additional spacing cannot be added to margins that are truncated or omitted due to unforced fragmentation breaks (see [CSS3-PAGE] and [CSS-BREAK-3]); therefore if block-step-insert is margin, all extra space derived from applying block-step-size must be inserted on the opposite side of the fragment (regardless of block-step-align).

### 2.4. Rounding Method: the block-step-round property

Name: | block-step-round
Value: | up | down | nearest
Initial: | up
Applies to: | block-level boxes
Inherited: | no
Percentages: | N/A
Computed value: | specified keyword
Canonical order: | per grammar
Animatable: | no
Animation type: | discrete

This property specifies whether adjustments due to block-step-size insert positive or negative space.

Values have the following meanings:

up
  The outer size of the box is increased (positive space is inserted) to fulfill the block-step-size constraint.
down
  The outer size of the box is decreased (negative space is inserted) to fulfill the block-step-size constraint.
nearest
  The outer size of the box is either increased (as for up) or decreased (as for down—whichever results in the smallest absolute change—to fulfill the block-step-size constraint. If both options would result in the same amount of change, the size is increased.

### 2.5. Block Step Adjustment Shorthand: the block-step shorthand

Name: | block-step
Value: | <'block-step-size'> || <'block-step-insert'> || <'block-step-align'> || <'block-step-round'>
Initial: | see individual properties
Applies to: | block-level boxes
Inherited: | no
Percentages: | N/A
Computed value: | see individual properties
Animation type: | see individual properties
Canonical order: | per grammar

This shorthand property allows for setting block-step-size, block-step-insert, block-step-align, and block-step-round in one declaration. Omitted values are set to the property’s initial value.

Authors are advised to use this shorthand rather than the longhands unless there is a specific need for its individual longhands to cascade independently.

## 3. Adjusting Line Box Heights: the line-height-step property

Name: | line-height-step
Value: | <length>
Initial: | 0px
Applies to: | block containers
Inherited: | yes
Percentages: | N/A
Computed value: | absolute length
Canonical order: | per grammar
Animatable: | no
Animation type: | by computed value type

This property defines the step unit for line box heights. A step unit is the length of the vertical rhythm, usually the distance from one baseline to the next baseline of the body text. Body text should fit into one step unit, and taller lines such as headings should have heights of two or more step units. Vertical rhythm is created by making heights of all lines an integer multiple of the step unit.

When the step unit is set to a positive <length>, the line box heights are rounded up to the closest multiple of the unit. Negative <length> values are invalid.

[CSS21] §10.8 Line height calculations defines how to compute the height of a line box from its inline-level content. The rounding is applied to the resulting height of the line box, and the additional space is distributed to over-side and under-side of the line box equally, so that the original line box appears at the center of the multiple of step unit. This adjustment is done by assuming that there is an inline-level box that has adjusted A' and D' in the line box. This inline-level box does not affect alignment points of the vertical-align property, except values that align relative to the line box.

Rounding up the computed line box height.

Should this be animatable? There doesn’t seem to be use cases but needed for consistency?

In the following example, the height of line box in each paragraph is rounded up to the step unit.

    :root {
      font-size: 12pt;
      --my-grid: 18pt;
      line-height-step: var(--my-grid);
    }
    h1 {
      font-size: 20pt;
      margin-top: calc(2 * var(--my-grid));
    }
    p {
      margin: 0;
    }

The line box in `<h1>` does not fit into one step unit and thus occupies two, but it is still centered within the two step unit.

Authors can keep margins or other properties to be multiple of step unit using var() and calc() as in the example above.

If author prefers, tools like Sass can make such declarations shorter.

    $gu: 18px;

    @function gu($n) {
      @return $n * $gu;
    }

    h1 {
      font-size: 20pt;
      margin: gu(1.2) auto gu(1.8);
    }

It is usually recommended to set the line-height lower than the step unit. The used line height can increase due to several factors such as the use of vertical-align or font fallback.

## 4. Privacy and Security Considerations

This specification introduces no new privacy leaks, or security considerations beyond "implement it correctly".

## 5. Acknowledgments

This specification would not have been possible without the help from: Masaharu Akutsu, Yoko Aoki, Takao Baba, Chris Eppstein, Ichiro Inaba, Jxck, Noriko Kase, Motoya Kinoshita, Shinyu Murakami, Tsutomu Nanjo, Kiyoshi Narishima, Charlie Neely, Takuya Nishimura, Katsuhiro Osumi, Florian Rivoal, Hiroshi Sakakibara, Alan Stearns, Masataka Yakura, KADOKAWA Corporation, PixelGrid Inc., and the CSS Working Group members.

## Conformance

### Document conventions

Conformance requirements are expressed with a combination of descriptive assertions and RFC 2119 terminology. The key words “MUST”, “MUST NOT”, “REQUIRED”, “SHALL”, “SHALL NOT”, “SHOULD”, “SHOULD NOT”, “RECOMMENDED”, “MAY”, and “OPTIONAL” in the normative parts of this document are to be interpreted as described in RFC 2119. However, for readability, these words do not appear in all uppercase letters in this specification.

All of the text of this specification is normative except sections explicitly marked as non-normative, examples, and notes. [RFC2119]

Examples in this specification are introduced with the words “for example” or are set apart from the normative text with `class="example"`, like this:

This is an example of an informative example.

Informative notes begin with the word “Note” and are set apart from the normative text with `class="note"`, like this:

Note, this is an informative note.

Advisements are normative sections styled to evoke special attention and are set apart from other normative text with `<strong class="advisement">`, like this: UAs MUST provide an accessible alternative.

### Conformance classes

Conformance to this specification is defined for three conformance classes:

style sheet
  A CSS style sheet.
renderer
  A UA that interprets the semantics of a style sheet and renders documents that use them.
authoring tool
  A UA that writes a style sheet.

A style sheet is conformant to this specification if all of its statements that use syntax defined in this module are valid according to the generic CSS grammar and the individual grammars of each feature defined in this module.

A renderer is conformant to this specification if, in addition to interpreting the style sheet as defined by the appropriate specifications, it supports all the features defined by this specification by parsing them correctly and rendering the document accordingly. However, the inability of a UA to correctly render a document due to limitations of the device does not make the UA non-conformant. (For example, a UA is not required to render color on a monochrome monitor.)

An authoring tool is conformant to this specification if it writes style sheets that are syntactically correct according to the generic CSS grammar and the individual grammars of each feature in this module, and meet all other conformance requirements of style sheets as described in this module.

### Requirements for Responsible Implementation of CSS

The following sections define several conformance requirements for implementing CSS responsibly, in a way that promotes interoperability in the present and future.

#### Partial Implementations

So that authors can exploit the forward-compatible parsing rules to assign fallback values, CSS renderers must treat as invalid (and ignore as appropriate) any at-rules, properties, property values, keywords, and other syntactic constructs for which they have no usable level of support. In particular, user agents must not selectively ignore unsupported property values and honor supported values in a single multi-value property declaration: if any value is considered invalid (as unsupported values must be), CSS requires that the entire declaration be ignored.

#### Implementations of Unstable and Proprietary Features

To avoid clashes with future stable CSS features, the CSSWG recommends following best practices for the implementation of unstable features and proprietary extensions to CSS.

#### Implementations of CR-level Features

Once a specification reaches the Candidate Recommendation stage, implementers should release an unprefixed implementation of any CR-level feature they can demonstrate to be correctly implemented according to spec, and should avoid exposing a prefixed variant of that feature.

To establish and maintain the interoperability of CSS across implementations, the CSS Working Group requests that non-experimental CSS renderers submit an implementation report (and, if necessary, the testcases used for that implementation report) to the W3C before releasing an unprefixed implementation of any CSS features. Testcases submitted to W3C are subject to review and correction by the CSS Working Group.

Further information on submitting testcases and implementation reports can be found from on the CSS Working Group’s website at http://www.w3.org/Style/CSS/Test/. Questions should be directed to the public-css-testsuite@w3.org mailing list.

## Index

### Terms defined by this specification

- auto, in §2.3
- block-step, in §2.5
- block-step-align, in §2.3
- block-step-insert, in §2.2
- block-step-round, in §2.4
- block-step-size, in §2.1
- center, in §2.3
- down, in §2.4
- end, in §2.3
- line-height-step, in §3
- margin, in §2.2
- nearest, in §2.4
- padding, in §2.2
- start, in §2.3
- step unit, in §3
- up, in §2.4

https://drafts.csswg.org/css-align-3/#propdef-align-self Referenced in:

- 2.3. Specifying Alignment: the block-step-align property

https://drafts.csswg.org/css-box-3/#propdef-margin Referenced in:

- 2.2. Specifying the Spacing Type: the block-step-insert property

https://drafts.csswg.org/css-box-3/#propdef-padding Referenced in:

- 2.2. Specifying the Spacing Type: the block-step-insert property

https://drafts.csswg.org/css-break-3/#fragment Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property

https://drafts.csswg.org/css-cascade-4/#shorthand-property Referenced in:

- 2.5. Block Step Adjustment Shorthand: the block-step shorthand

https://drafts.csswg.org/css-display-3/#establish-an-independent-formatting-context Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property

https://drafts.csswg.org/css-inline-3/#propdef-vertical-align Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property (2)

https://drafts.csswg.org/css-line-grid-1/#propdef-line-grid Referenced in:

- 1.1. East Asian Casual Vertical Rhythms (2)

https://drafts.csswg.org/css-values-3/#length-value Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property (2) (3)
- 3. Adjusting Line Box Heights: the line-height-step property (2) (3)

https://drafts.csswg.org/css-values-4/#funcdef-calc Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property

https://drafts.csswg.org/css-values-4/#comb-one Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property
- 2.2. Specifying the Spacing Type: the block-step-insert property
- 2.3. Specifying Alignment: the block-step-align property (2) (3)
- 2.4. Rounding Method: the block-step-round property (2)

https://drafts.csswg.org/css-values-4/#comb-any Referenced in:

- 2.5. Block Step Adjustment Shorthand: the block-step shorthand (2) (3)

https://drafts.csswg.org/css-variables-1/#funcdef-var Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property

https://drafts.csswg.org/css-writing-modes-4/#block-size Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property

https://drafts.csswg.org/css-writing-modes-4/#end Referenced in:

- 2.3. Specifying Alignment: the block-step-align property

https://drafts.csswg.org/css-writing-modes-4/#over Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property

https://drafts.csswg.org/css-writing-modes-4/#start Referenced in:

- 2.3. Specifying Alignment: the block-step-align property

https://drafts.csswg.org/css-writing-modes-4/#under Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property

https://drafts.csswg.org/css2/visudet.html#propdef-line-height Referenced in:

- 3. Adjusting Line Box Heights: the line-height-step property

### Terms defined by reference

- [css-align-3] defines the following terms:
  - align-self
- [css-box-3] defines the following terms:
  - margin
  - padding
- [CSS-BREAK-3] defines the following terms:
  - fragment
- [css-cascade-4] defines the following terms:
  - shorthand property
- [css-display-3] defines the following terms:
  - establish an independent formatting context
- [css-inline-3] defines the following terms:
  - vertical-align
- [css-line-grid-1] defines the following terms:
  - line-grid
- [css-values-3] defines the following terms:
  - <length>
- [css-values-4] defines the following terms:
  - calc()
  - |
  - ||
- [css-variables-1] defines the following terms:
  - var()
- [css-writing-modes-4] defines the following terms:
  - block size
  - end
  - over
  - start
  - under
- [CSS21] defines the following terms:
  - line-height

## References

### Normative References

[CSS-ALIGN-3]
  Elika Etemad; Tab Atkins Jr.. CSS Box Alignment Module Level 3. 6 December 2018. WD. URL: https://www.w3.org/TR/css-align-3/
[CSS-BOX-3]
  Elika Etemad. CSS Box Model Module Level 3. 18 December 2018. WD. URL: https://www.w3.org/TR/css-box-3/
[CSS-BREAK-3]
  Rossen Atanassov; Elika Etemad. CSS Fragmentation Module Level 3. 4 December 2018. CR. URL: https://www.w3.org/TR/css-break-3/
[CSS-CASCADE-4]
  Elika Etemad; Tab Atkins Jr.. CSS Cascading and Inheritance Level 4. 28 August 2018. CR. URL: https://www.w3.org/TR/css-cascade-4/
[CSS-DISPLAY-3]
  Tab Atkins Jr.; Elika Etemad. CSS Display Module Level 3. 28 August 2018. CR. URL: https://www.w3.org/TR/css-display-3/
[CSS-INLINE-3]
  Dave Cramer; Elika Etemad; Steve Zilles. CSS Inline Layout Module Level 3. 8 August 2018. WD. URL: https://www.w3.org/TR/css-inline-3/
[CSS-LINE-GRID-1]
  Elika Etemad; Koji Ishii; Alan Stearns. CSS Line Grid Module Level 1. 16 September 2014. WD. URL: https://www.w3.org/TR/css-line-grid-1/
[CSS-VALUES-3]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 3. 31 January 2019. CR. URL: https://www.w3.org/TR/css-values-3/
[CSS-VALUES-4]
  Tab Atkins Jr.; Elika Etemad. CSS Values and Units Module Level 4. 31 January 2019. WD. URL: https://www.w3.org/TR/css-values-4/
[CSS-WRITING-MODES-4]
  Elika Etemad; Koji Ishii. CSS Writing Modes Level 4. 24 May 2018. CR. URL: https://www.w3.org/TR/css-writing-modes-4/
[CSS21]
  Bert Bos; et al. Cascading Style Sheets Level 2 Revision 1 (CSS 2.1) Specification. 7 June 2011. REC. URL: https://www.w3.org/TR/CSS2/
[RFC2119]
  S. Bradner. Key words for use in RFCs to Indicate Requirement Levels. March 1997. Best Current Practice. URL: https://tools.ietf.org/html/rfc2119

### Informative References

[CSS-VARIABLES-1]
  Tab Atkins Jr.. CSS Custom Properties for Cascading Variables Module Level 1. 3 December 2015. CR. URL: https://www.w3.org/TR/css-variables-1/
[CSS3-PAGE]
  Elika Etemad; Simon Sapin. CSS Paged Media Module Level 3. 18 October 2018. WD. URL: https://www.w3.org/TR/css-page-3/

## Property Index

Name | Value | Initial | Applies to | Inh. | %ages | Animatable | Animation type | Canonical order | Computed value
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
block-step | <'block-step-size'> || <'block-step-insert'> || <'block-step-align'> || <'block-step-round'> | see individual properties | block-level boxes | no | N/A |  | see individual properties | per grammar | see individual properties
block-step-align | auto | center | start | end | auto | block-level boxes | no | N/A | no | discrete | per grammar | specified keyword
block-step-insert | margin | padding | margin | block-level boxes | no | N/A | no | discrete | per grammar | specified keyword
block-step-round | up | down | nearest | up | block-level boxes | no | N/A | no | discrete | per grammar | specified keyword
block-step-size | none | <length> | none | block-level boxes | no | N/A | ??? | by computed value type | per grammar | specified keyword or absolute length
line-height-step | <length> | 0px | block containers | yes | N/A | no | by computed value type | per grammar | absolute length

## Issues Index

This proposal can be simplified down to just the block-step-size property, represented solely through its shortened form as block-step. This level will likely at most contain block-step-size and block-step-insert, leaving block-step-align and block-step-round to be added if the future demands. The full design is described herein for current discussion and future reference. ↵
This proposal is currently defined to apply only to block-level boxes. This limitation is solely to simplify the first iteration; it should eventually be extended to all layout modes that honor specified heights. ↵
Should this be animatable? There doesn’t seem to be use cases but needed for consistency? ↵
#propdef-block-step-size Referenced in:

- 2. Adjusting Block-level Box Heights (2)
- 2.1. Specifying the Step Size: the block-step-size property
- 2.2. Specifying the Spacing Type: the block-step-insert property (2) (3)
- 2.3. Specifying Alignment: the block-step-align property (2) (3) (4) (5)
- 2.4. Rounding Method: the block-step-round property (2) (3) (4)
- 2.5. Block Step Adjustment Shorthand: the block-step shorthand (2)

#propdef-block-step-insert Referenced in:

- 2. Adjusting Block-level Box Heights
- 2.2. Specifying the Spacing Type: the block-step-insert property
- 2.3. Specifying Alignment: the block-step-align property (2)
- 2.5. Block Step Adjustment Shorthand: the block-step shorthand (2)

#valdef-block-step-insert-margin Referenced in:

- 2.3. Specifying Alignment: the block-step-align property (2)

#propdef-block-step-align Referenced in:

- 2. Adjusting Block-level Box Heights
- 2.3. Specifying Alignment: the block-step-align property (2)
- 2.5. Block Step Adjustment Shorthand: the block-step shorthand (2)

#valdef-block-step-align-center Referenced in:

- 2.3. Specifying Alignment: the block-step-align property (2)

#valdef-block-step-align-start Referenced in:

- 2.3. Specifying Alignment: the block-step-align property

#valdef-block-step-align-end Referenced in:

- 2.3. Specifying Alignment: the block-step-align property

#propdef-block-step-round Referenced in:

- 2. Adjusting Block-level Box Heights
- 2.1. Specifying the Step Size: the block-step-size property
- 2.4. Rounding Method: the block-step-round property
- 2.5. Block Step Adjustment Shorthand: the block-step shorthand (2)

#valdef-block-step-align-up Referenced in:

- 2.4. Rounding Method: the block-step-round property

#valdef-block-step-align-down Referenced in:

- 2.4. Rounding Method: the block-step-round property

#propdef-block-step Referenced in:

- 1.1. East Asian Casual Vertical Rhythms (2)
- 2. Adjusting Block-level Box Heights (2)
- 2.5. Block Step Adjustment Shorthand: the block-step shorthand

#propdef-line-height-step Referenced in:

- 1.1. East Asian Casual Vertical Rhythms (2)
- 3. Adjusting Line Box Heights: the line-height-step property

#step-unit Referenced in:

- 2.1. Specifying the Step Size: the block-step-size property (2)
- 3. Adjusting Line Box Heights: the line-height-step property (2) (3) (4) (5) (6) (7) (8) (9) (10) (11)